import { QRL, Signal } from "@builder.io/qwik";
import { type SearchParamSerializer } from "./parsers";
export * from "./parsers";
export type UseQuerySignalOptions = {
    forceReload?: boolean;
    replaceState?: boolean;
    scroll?: boolean;
};
export interface ParserBuilderOptions<T> {
    serialize: (value: T | undefined | null) => string | undefined | null;
    parse: (stringValue: string | null) => T | undefined;
}
export declare function useSignalAndDebounced<T>(debounce: number, initialValue?: T): [
    nonDebounced: Signal<T | undefined>,
    debounced: Readonly<Signal<T | undefined>>
];
export declare function useQuerySignal<T>(queryKey: string, serializer: SearchParamSerializer<T>, options?: UseQuerySignalOptions): Signal<T | undefined>;
export declare function useQuerySignalDebounced<T>(queryKey: string, serializer: SearchParamSerializer<T>, debounce?: number, options?: UseQuerySignalOptions): [
    nonDebounced: Signal<T | undefined>,
    debounced: Readonly<Signal<T | undefined>>
];
export declare function useQueryStringSignal(queryKey: string, defaultValue?: string, options?: UseQuerySignalOptions): Signal<string | undefined>;
export declare function useQueryArraySignal<T>(queryKey: string, separator: string, itemSerializer: SearchParamSerializer<T>, defaultValue?: T[], options?: UseQuerySignalOptions): Signal<T[] | undefined>;
export declare function useQueryArraySignalDebounced<T>(queryKey: string, separator: string, itemSerializer: SearchParamSerializer<T>, defaultValue?: T[], debounce?: number, options?: UseQuerySignalOptions): [
    nonDebounced: Signal<T[] | undefined>,
    debounced: Readonly<Signal<T[] | undefined>>
];
export type FilterFunction<T, TFiltered, TFilterContext> = (arg: {
    context: Signal<TFilterContext | undefined>;
    currentValue: T | undefined;
    filtered: Signal<TFiltered | undefined>;
    cleanup: (callback: () => void) => void;
}) => void;
export declare function useSignalAndFiltered<T, TFiltered, TFilterContext>(filterFunction$: QRL<FilterFunction<T, TFiltered, TFilterContext>>, initialContext?: TFilterContext, initialValue?: T): [
    value: Signal<T | undefined>,
    filtered: Readonly<Signal<TFiltered | undefined>>
];
